/* Test program that shows the provided command line parameters
 * either in a PM message box or prints them to stdout.
 * The ouput type depends on how the executable has been marked
 * at link-time.
 */

#include <stdio.h>
#include <string.h>

#define INCL_DOSERRORS
#define INCL_DOSPROCESS
#define INCL_WINDIALOGS
#include <os2.h>

/********************************************/

static int IS_PM_APP = 0;

/********************************************/

static void showMessage(const char * title, const char * message)
{
    if (IS_PM_APP)
    {
        /* show message box with usage */
        const HAB hab = WinInitialize(0);
        if (hab != 0)
        {
            const HMQ hmq = WinCreateMsgQueue(hab, 0);
            if (hmq != 0)
            {
                WinMessageBox(HWND_DESKTOP, HWND_DESKTOP, (PSZ)message, (PSZ)title, 0, 
                              MB_MOVEABLE | MB_OK | MB_NOICON);
                WinDestroyMsgQueue(hmq);
            }
            WinTerminate(hab);
        }
    }
    else
    {
        printf("%s\n", message);
    }
}

/********************************************/
/********************************************/

int main(int argc, char * argv[])
{
    int i;

    /* GCC runtime does not provide the fully qualified name. */
    /* But we can query it from the OS. */
    PTIB ptib;
    PPIB ppib;
    DosGetInfoBlocks( &ptib, &ppib);

    /* remember whether we don't have a console but rather the PM */
    IS_PM_APP = (ppib->pib_ultype == 3);

    {
        char msg[5000] = { 0 };
        int  bufferpos = 0;

        for (i = 1; i < argc; i++)
        {
            if (bufferpos + strlen(argv[i] + 1) > sizeof(msg)-1)
            {
                /* buffer limit reached */
                return 1;
            }
            strcat(msg, argv[i]);
            if (i + 1 < argc)
            {
                strcat(msg, "\n");
            }
        }
        showMessage("Child process ommand line arguments", msg);
    }

    return 0;
}


